@@ -1,3 +1,4 @@
+import datetime
 import yaml
 
 from superdate import SuperDate
@@ -50,7 +51,7 @@ class Attributes(dict):
 
         for k, v in d.items():
             if v and (k in dtfields or 'date' in k):
-                d[k] = v.strftime('%Y-%m-%d, %a')
+                d[k] = str(v._date)
 
         return d
 
